==> udtheme-6.x-5.3.tar.gz: udtheme/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3.2.2 2009/10/02 03:21:33 mtecknology Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head; ?>
    <?php print $styles; ?>
    <?php print $scripts; ?>
    <?php print $iepatch; ?>
    <!--[if IE 6]> <?php print $iehack[6]; ?> <![endif]-->
    <!--[if IE 7]> <?php print $iehack[7]; ?> <![endif]-->
    <!--[if IE 8]> <?php print $iehack[8]; ?> <![endif]-->
  </head>
  <body>
    <!-- Banner -->
    <?php print $banner; ?>
    <!-- Layout -->
    <div id="page-top-border"></div>
    <div id="wrapper" style="width: <?php print pagewidth(); ?>px;">
      <div id="page-border-left" style="width:<?php print pagewidth(14); ?>px;">
        <div id="page-border-right">
          <div id="page-content">
            <div id="bg-top"></div>
            <div id="topNav">
              <div id="nav-content">
                <div id="nav" class="menu">
                  <?php print $topmenu; ?>
                  <div style="clear: both;"></div>
                </div>
                <?php print $search_box; ?>
                <?php print $logo; ?>
                <div class="clear">
                  <?php print $spacergif; ?>
                </div>
              </div>
              <!-- /#nav-content -->
            </div>
            <!-- /#topNav -->
            <div id="header" style="width:<?php print pagewidth(24); ?>px">
              <?php print $site_name; ?>
              <?php print $site_slogan; ?>
              <!-- <?php print $secondary_links; ?> -->
              <?php print $header; ?>
            </div>
            <!-- /#header -->
            <div id="container">
              <?php if ($left) { ?>
                <div id="column-left">
                  <?php print $left; ?>
                </div>
              <?php } ?>
              <?php if ($right) { ?>
                <div id="column-right">
                  <?php print $right; ?>
                </div>
              <?php } ?>
              <div id="column-center">
                <?php print $breadcrumb; ?>
                <?php print $center; ?>
              </div>
            </div>
            <!-- /#container -->
            <div id="footer" class="clear">
              <?php print $footer; ?>
              <div class="wrapper">
                <?php print $rulebar; ?>
                <div class="paragraph">
                  <div id="leftfooter">
                    <?php print $leftfooter; ?>
                  </div>
                  <div id="rightfooter">
                    <?php print $rightfooter; ?>
                  </div>
                </div>
              </div>
            </div>
            <!-- /#footer -->
          </div>
          <!-- /#page-content -->
          <div id="bg-bottom"></div>
          <div id="bg-right">&#160;</div>
          <div id="bottom-right">&#160;</div>
        </div>
        <!-- /#page-border-right -->
        <div id="bg-left">&#160;</div>
        <div id="bottom-left">&#160;</div>
      </div>
      <!-- /#page-border-left -->
    </div>
    <!-- /#wrapper -->
    <!-- /layout -->
    <?php print $closure; ?>
  </body>
</html>

==> udtheme-6.x-5.4.tar.gz: udtheme/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3.2.3 2009/10/24 00:53:08 mtecknology Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head; ?>
    <?php print $styles; ?>
    <?php print $scripts; ?>
    <?php print $iehack; ?>
  </head>
  <body>
    <!-- Banner -->
    <?php print $banner; ?>
    <!-- Layout -->
    <div id="page-top-border"></div>
    <div id="wrapper" style="width: <?php print pagewidth() . widthtype(); ?>;">
      <div id="page-border-left">
        <div id="page-border-right">
          <div id="page-content">
            <div id="bg-top"></div>
            <div id="topNav">
              <div id="nav-content">
                <div id="nav" class="menu">
                  <?php print $topmenu; ?>
                  <div style="clear: both;"></div>
                </div>
                <?php print $search_box; ?>
                <?php print $logo; ?>
                <div class="clear">
                  <?php print $spacergif; ?>
                </div>
              </div>
              <!-- /#nav-content -->
            </div>
            <!-- /#topNav -->
            <div id="header">
              <?php print $site_name; ?>
              <?php print $site_slogan; ?>
              <?php print $header; ?>
            </div>
            <!-- /#header -->
            <div id="container">
              <?php if ($left) { ?>
                <div id="column-left">
                  <?php print $left; ?>
                </div>
              <?php } ?>
              <?php if ($right) { ?>
                <div id="column-right">
                  <?php print $right; ?>
                </div>
              <?php } ?>
              <div id="column-center">
                <?php print $breadcrumb; ?>
                <?php print $center; ?>
              </div>
            </div>
            <!-- /#container -->
            <div id="footer" class="clear">
              <?php print $footer; ?>
              <div class="wrapper">
                <?php print $rulebar; ?>
                <div class="paragraph">
                  <div id="leftfooter">
                    <?php print $leftfooter; ?>
                  </div>
                  <div id="rightfooter">
                    <?php print $rightfooter; ?>
                  </div>
                </div>
              </div>
            </div>
            <!-- /#footer -->
          </div>
          <!-- /#page-content -->
          <div id="bg-bottom"></div>
          <div id="bg-right">&#160;</div>
          <div id="bottom-right">&#160;</div>
        </div>
        <!-- /#page-border-right -->
        <div id="bg-left">&#160;</div>
        <div id="bottom-left">&#160;</div>
      </div>
      <!-- /#page-border-left -->
    </div>
    <!-- /#wrapper -->
    <!-- /layout -->
    <?php print $closure; ?>
  </body>
</html>
